Class: Usps::Support::Models::Hq::SharedRecord

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
lib/usps/support/models/hq/shared_record.rb

Overview

Base record for the HQ VHQAB database

rubocop:disable Rails/ApplicationRecord

Class Method Summary collapse

Class Method Details

.allow_hq_database_edits?Boolean

Returns:

  • (Boolean)


12
# File 'lib/usps/support/models/hq/shared_record.rb', line 12

def self.allow_hq_database_edits? = false

.ignore_type_column_sti!Object

The database has a ‘type` column, which gets confused with Rails STI

As long as we don’t need to set the column to anything specific, this helper cleans up the repeated use case of ignoring it.



19
# File 'lib/usps/support/models/hq/shared_record.rb', line 19

def self.ignore_type_column_sti! = self.inheritance_column = nil