Class: Usps::Support::Models::Hq::SharedRecord
- Inherits:
-
ActiveRecord::Base
- Object
- ActiveRecord::Base
- Usps::Support::Models::Hq::SharedRecord
- Defined in:
- lib/usps/support/models/hq/shared_record.rb
Overview
Base record for the HQ VHQAB database
rubocop:disable Rails/ApplicationRecord
Direct Known Subclasses
Members::BaseRecord, Usps::Support::Models::Hq::Squadrons::BaseRecord
Class Method Summary collapse
- .allow_hq_database_edits? ⇒ Boolean
-
.ignore_type_column_sti! ⇒ Object
The database has a ‘type` column, which gets confused with Rails STI.
Class Method Details
.allow_hq_database_edits? ⇒ Boolean
12 |
# File 'lib/usps/support/models/hq/shared_record.rb', line 12 def self.allow_hq_database_edits? = false |
.ignore_type_column_sti! ⇒ Object
The database has a ‘type` column, which gets confused with Rails STI
As long as we don’t need to set the column to anything specific, this helper cleans up the repeated use case of ignoring it.
19 |
# File 'lib/usps/support/models/hq/shared_record.rb', line 19 def self.ignore_type_column_sti! = self.inheritance_column = nil |